==> mx-welcome_18.12.07.tar.xz: mx-welcome-18.12.07/translations/mx-welcome_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>You must run this program as normal user.</source>
        <translation>Πρέπει να τρέξετε αυτή την εφαρμογή ως κανονικός χρήστης</translation>
    </message>
</context>
<context>
    <name>mxwelcome</name>
    <message>
        <location filename="../mxwelcome.ui" line="14"/>
        <location filename="../mxwelcome.cpp" line="54"/>
        <location filename="../mxwelcome.cpp" line="99"/>
        <location filename="../mxwelcome.cpp" line="111"/>
        <source>MX Welcome</source>
        <translation>MX Welcome</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="70"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Welcome to MX Linux, a fast, friendly, and stable OS loaded with amazing tools and supported by a great community. &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Καλώς ήρθατε στο MX Linux - ένα φιλικό, γρήγορο, σταθερό λειτουργικό σύστημα- φορτωμένο με καταπληκτικά εργαλεία και υποστηρίζεται από μια μεγάλη κοινότητα. &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="512"/>
        <source>Codecs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="576"/>
        <source>Users Manual</source>
        <translation>Εγχειρίδιο</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="203"/>
        <source>Forums</source>
        <translation>Φόρουμ</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="280"/>
        <source>Videos</source>
        <translation>βίντεο</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="544"/>
        <source>Wiki</source>
        <translation>Wiki</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="486"/>
        <source>Tools</source>
        <translation>Εργαλεία </translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="377"/>
        <source>Contribute</source>
        <translation>Συνεισφέρω</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="422"/>
        <source>Tweak (Panel, etc...)</source>
        <translation>Τροποποίησες</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="113"/>
        <source>Popular Apps</source>
        <translation>δημοφιλείς εφαρμογές</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:14pt; font-weight:600;&quot;&gt;MX-17 &amp;quot;Horizon&amp;quot;&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:14pt; font-weight:600;&quot;&gt;MX-17 &amp;quot;Horizon&amp;quot;&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Login Info</source>
        <translation type="vanished">Πληροφορίες Login</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="608"/>
        <source>FAQ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="641"/>
        <source>Show this dialog at start up</source>
        <translation>Εμφάνιση αυτού του διαλόγου κατά την εκκίνηση</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="706"/>
        <source>About this application</source>
        <translation>Περί εφαρμογής.</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="709"/>
        <source>About...</source>
        <translation>Περί</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="716"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="770"/>
        <source>Quit application</source>
        <translation>Κλείστε την εφαρμογή </translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="773"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="780"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="98"/>
        <source>About MX Welcome</source>
        <translation>Περί MX Welcome</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="99"/>
        <source>Version: </source>
        <translation>Έκδοση:</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="100"/>
        <source>Program for displaying a welcome screen in MX Linux</source>
        <translation>Πρόγραμμα για την εμφάνιση μια ευπρόσδεκτη οθόνη MX Linux</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="102"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c)  MX Linux </translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="103"/>
        <source>License</source>
        <translation>Άδεια</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="104"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="105"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="121"/>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <source>Live Login Info</source>
        <translation type="vanished">Πληροφορίες Login</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="57"/>
        <source>Default username:  &lt;b&gt;demo&lt;/b&gt; &lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Default demo password:  &lt;b&gt;demo&lt;/b&gt;</source>
        <translation>Προεπιλεγμένο όνομα χρήστη: &lt;b&gt;demo&lt;/b&gt;&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;Προεπιλεγμένος κωδικός πρόσβασης του demo&lt;b&gt;demo&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="58"/>
        <source>&lt;b&gt;Root&lt;/b&gt; Password:  &lt;b&gt;root&lt;/b&gt;&lt;/p&gt; </source>
        <translation>Κωδικός πρόσβασης &lt;b&gt;root&lt;/b&gt;: &lt;b&gt;root&lt;/b&gt;&lt;/p&gt;</translation>
    </message>
</context>
</TS>

==> mx-welcome_19.1.tar.xz: mx-welcome-19.1/translations/mx-welcome_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>You must run this program as normal user.</source>
        <translation>Πρέπει να τρέξετε αυτή την εφαρμογή ως κανονικός χρήστης</translation>
    </message>
</context>
<context>
    <name>mxwelcome</name>
    <message>
        <location filename="../mxwelcome.ui" line="14"/>
        <location filename="../mxwelcome.cpp" line="54"/>
        <location filename="../mxwelcome.cpp" line="99"/>
        <location filename="../mxwelcome.cpp" line="111"/>
        <source>MX Welcome</source>
        <translation>MX Welcome</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="70"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Welcome to MX Linux, a fast, friendly, and stable OS loaded with amazing tools and supported by a great community. &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Καλώς ήρθατε στο MX Linux - ένα φιλικό, γρήγορο, σταθερό λειτουργικό σύστημα- φορτωμένο με καταπληκτικά εργαλεία και υποστηρίζεται από μια μεγάλη κοινότητα. &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="113"/>
        <source>Popular Apps</source>
        <translation>δημοφιλείς εφαρμογές</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="203"/>
        <source>Forums</source>
        <translation>Φόρουμ</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="280"/>
        <source>Videos</source>
        <translation>βίντεο</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="377"/>
        <source>Contribute</source>
        <translation>Συνεισφέρω</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="422"/>
        <source>Tweak (Panel, etc...)</source>
        <translation>Τροποποίησες</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="486"/>
        <source>Tools</source>
        <translation>Εργαλεία </translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="512"/>
        <source>Codecs</source>
        <translation>Codecs</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="544"/>
        <source>Wiki</source>
        <translation>Wiki</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="576"/>
        <source>Users Manual</source>
        <translation>Εγχειρίδιο</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="608"/>
        <source>FAQ</source>
        <translation>Συχνές ερωτήσεις</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="641"/>
        <source>Show this dialog at start up</source>
        <translation>Εμφάνιση αυτού του διαλόγου κατά την εκκίνηση</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="706"/>
        <source>About this application</source>
        <translation>Περί εφαρμογής.</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="709"/>
        <source>About...</source>
        <translation>Περί</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="716"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="770"/>
        <source>Quit application</source>
        <translation>Κλείστε την εφαρμογή </translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="773"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../mxwelcome.ui" line="780"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="57"/>
        <source>Default username:  &lt;b&gt;demo&lt;/b&gt; &lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Default demo password:  &lt;b&gt;demo&lt;/b&gt;</source>
        <translation>Προεπιλεγμένο όνομα χρήστη: &lt;b&gt;demo&lt;/b&gt;&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;Προεπιλεγμένος κωδικός πρόσβασης του demo&lt;b&gt;demo&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="58"/>
        <source>&lt;b&gt;Root&lt;/b&gt; Password:  &lt;b&gt;root&lt;/b&gt;&lt;/p&gt; </source>
        <translation>Κωδικός πρόσβασης &lt;b&gt;root&lt;/b&gt;: &lt;b&gt;root&lt;/b&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="98"/>
        <source>About MX Welcome</source>
        <translation>Περί MX Welcome</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="99"/>
        <source>Version: </source>
        <translation>Έκδοση:</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="100"/>
        <source>Program for displaying a welcome screen in MX Linux</source>
        <translation>Πρόγραμμα για την εμφάνιση μια ευπρόσδεκτη οθόνη MX Linux</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="102"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c)  MX Linux </translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="103"/>
        <source>License</source>
        <translation>Άδεια</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="104"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="105"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <location filename="../mxwelcome.cpp" line="121"/>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
</context>
</TS>
